PyMICE Python library
=====================

PyMICE is a Python™ library for mice behavioural data analysis.

The library can be used for loading and analysing of data obtained
from IntelliCage™ system in an intuitive way in Python programming language.

The library provides user with an object oriented application programming
interface (API) and a data abstraction layer. It also comes with auxiliary
tools supporting development of analysis workflows, like data validators and
a tool for workflow configuration.

For more details please see `The project website
<https://neuroinflab.wordpress.com/research/pymice/>`_.
